
```{include} ../README.md
```

```{toctree}
:maxdepth: 1
:caption: Contents

installation
Getting started <example>
api/references
contributing
```

### Indices and tables

* [Index](genindex)
* [Search](search)
